@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # SPDX-License-Identifier: Apache-2.0
 # Copyright 2018-2021 Michael R. Crusoe
-"""CWL Expression refactoring tool for CWL v1.1 ."""
+"""CWL Expression refactoring tool for CWL v1.0 ."""
 import copy
 import hashlib
 from collections.abc import Mapping
@@ -22,8 +22,8 @@ from ruamel import yaml
 from schema_salad.sourceline import SourceLine
 from schema_salad.utils import json_dumps
 
-import cwl_utils.parser.cwl_v1_1 as cwl
-import cwl_utils.parser.cwl_v1_1_utils as utils
+import cwl_utils.parser.cwl_v1_0 as cwl
+import cwl_utils.parser.cwl_v1_0_utils as utils
 from cwl_utils.errors import JavascriptException, WorkflowException
 from cwl_utils.expression import do_eval, interpolate
 from cwl_utils.types import CWLObjectType, CWLOutputType
@@ -236,7 +236,7 @@ def traverse(
                     )
                 )
                 wf_inputs.append(
-                    cwl.WorkflowInputParameter(
+                    cwl.InputParameter(
                         id=inp_id,
                         label=inp.label,
                         secondaryFiles=inp.secondaryFiles,
@@ -324,13 +324,13 @@ def load_step(
 
 def generate_etool_from_expr(
     expr: str,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     no_inputs: bool = False,
     self_type: Optional[
         Union[
-            cwl.WorkflowInputParameter,
+            cwl.InputParameter,
             cwl.CommandInputParameter,
-            List[Union[cwl.WorkflowInputParameter, cwl.CommandInputParameter]],
+            List[Union[cwl.InputParameter, cwl.CommandInputParameter]],
         ]
     ] = None,  # if the "self" input should be a different type than the "result" output
     extra_processes: Optional[
@@ -346,28 +346,36 @@ def generate_etool_from_expr(
             new_type: Union[
                 List[Union[cwl.ArraySchema, cwl.InputRecordSchema]],
                 Union[cwl.ArraySchema, cwl.InputRecordSchema],
-            ] = [clean_type_ids(t.type_) for t in self_type]
-        else:
+            ] = [clean_type_ids(t.type_) for t in self_type if t.type_]
+        elif self_type.type_:
             new_type = clean_type_ids(self_type.type_)
+        else:
+            raise WorkflowException(f"Don't know how to make type from {self_type!r}.")
         inputs.append(
-            cwl.WorkflowInputParameter(
+            cwl.InputParameter(
                 id="self",
                 label=self_type.label if not isinstance(self_type, list) else None,
-                secondaryFiles=self_type.secondaryFiles
-                if not isinstance(self_type, list)
-                else None,
-                streamable=self_type.streamable
-                if not isinstance(self_type, list)
-                else None,
+                secondaryFiles=(
+                    self_type.secondaryFiles
+                    if not isinstance(self_type, list)
+                    else None
+                ),
+                streamable=(
+                    self_type.streamable if not isinstance(self_type, list) else None
+                ),
                 doc=self_type.doc if not isinstance(self_type, list) else None,
                 format=self_type.format if not isinstance(self_type, list) else None,
                 type_=new_type,
-                extension_fields=self_type.extension_fields
-                if not isinstance(self_type, list)
-                else None,
-                loadingOptions=self_type.loadingOptions
-                if not isinstance(self_type, list)
-                else None,
+                extension_fields=(
+                    self_type.extension_fields
+                    if not isinstance(self_type, list)
+                    else None
+                ),
+                loadingOptions=(
+                    self_type.loadingOptions
+                    if not isinstance(self_type, list)
+                    else None
+                ),
             )
         )
     outputs = yaml.comments.CommentedSeq()
@@ -448,7 +456,7 @@ def replace_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     source: Optional[Union[str, List[Any]]],
     replace_etool: bool = False,
     extra_process: Optional[
@@ -617,9 +625,7 @@ def process_workflow_inputs_and_outputs(
                     raise_type=WorkflowException,
                 ).makeError(TOPLEVEL_FORMAT_EXPR_ERROR.format(param.id.split("#")[-1]))
             if param.secondaryFiles:
-                if hasattr(param.secondaryFiles, "pattern") and get_expression(
-                    param.secondaryFiles.pattern, inputs, EMPTY_FILE
-                ):
+                if get_expression(param.secondaryFiles, inputs, EMPTY_FILE):
                     raise SourceLine(
                         param.loadingOptions.original_doc,
                         "secondaryFiles",
@@ -627,7 +633,7 @@ def process_workflow_inputs_and_outputs(
                     ).makeError(TOPLEVEL_SF_EXPR_ERROR.format(param.id.split("#")[-1]))
                 elif isinstance(param.secondaryFiles, MutableSequence):
                     for index2, entry in enumerate(param.secondaryFiles):
-                        if get_expression(entry.pattern, inputs, EMPTY_FILE):
+                        if get_expression(entry, inputs, EMPTY_FILE):
                             raise SourceLine(
                                 param.loadingOptions.original_doc,
                                 index2,
@@ -679,7 +685,7 @@ def process_workflow_reqs_and_hints(
                             expression = get_expression(envDef.envValue, inputs, None)
                             if expression:
                                 modified = True
-                                target = cwl.WorkflowInputParameter(
+                                target = cwl.InputParameter(
                                     id=None,
                                     type_="string",
                                 )
@@ -710,7 +716,7 @@ def process_workflow_reqs_and_hints(
                         expression = get_expression(this_attr, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(id=None, type_="long")
+                            target = cwl.InputParameter(id=None, type_="long")
                             etool_id = (
                                 "_expression_workflow_ResourceRequirement_{}".format(
                                     attr
@@ -737,7 +743,7 @@ def process_workflow_reqs_and_hints(
                         expression = get_expression(req.listing, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(
+                            target = cwl.InputParameter(
                                 id=None,
                                 type_=cwl.InputArraySchema(
                                     ["File", "Directory"], "array", None, None
@@ -763,7 +769,7 @@ def process_workflow_reqs_and_hints(
                             expression = get_expression(entry, inputs, None)
                             if expression:
                                 modified = True
-                                target = cwl.WorkflowInputParameter(
+                                target = cwl.InputParameter(
                                     id=None,
                                     type_=cwl.InputArraySchema(
                                         ["File", "Directory"], "array", None, None
@@ -806,7 +812,7 @@ def process_workflow_reqs_and_hints(
                                                 or expr_result["class"] == "Directory"
                                             )
                                         ):
-                                            target = cwl.WorkflowInputParameter(
+                                            target = cwl.InputParameter(
                                                 id=None,
                                                 type_=expr_result["class"],
                                             )
@@ -818,16 +824,16 @@ def process_workflow_reqs_and_hints(
                                                 None,
                                                 replace_etool,
                                             )
-                                            iwdr.listing[
-                                                index
-                                            ] = "$(inputs._iwdr_listing_{}".format(
-                                                index
+                                            iwdr.listing[index] = (
+                                                "$(inputs._iwdr_listing_{}".format(
+                                                    index
+                                                )
                                             )
                                             generated_iwdr_reqs.append(
                                                 (etool_id, index)
                                             )
                                         elif isinstance(expr_result, str):
-                                            target = cwl.WorkflowInputParameter(
+                                            target = cwl.InputParameter(
                                                 id=None,
                                                 type_=["File"],
                                             )
@@ -859,9 +865,9 @@ def process_workflow_reqs_and_hints(
                                             None,
                                             replace_etool,
                                         )
-                                        iwdr.listing[
-                                            index
-                                        ] = f"$(inputs._iwdr_listing_{index}"
+                                        iwdr.listing[index] = (
+                                            f"$(inputs._iwdr_listing_{index}"
+                                        )
                                         generated_iwdr_reqs.append((etool_id, index))
 
                                 elif entry.entryname:
@@ -870,7 +876,7 @@ def process_workflow_reqs_and_hints(
                                     )
                                     if expression:
                                         modified = True
-                                        target = cwl.WorkflowInputParameter(
+                                        target = cwl.InputParameter(
                                             id=None,
                                             type_="string",
                                         )
@@ -885,9 +891,9 @@ def process_workflow_reqs_and_hints(
                                             None,
                                             replace_etool,
                                         )
-                                        iwdr.listing[
-                                            index
-                                        ] = f"$(inputs._iwdr_listing_{index}"
+                                        iwdr.listing[index] = (
+                                            f"$(inputs._iwdr_listing_{index}"
+                                        )
                                         generated_iwdr_reqs.append((etool_id, index))
                         if generated_iwdr_reqs:
                             prop_reqs += (cwl.InitialWorkDirRequirement,)
@@ -1002,7 +1008,7 @@ def process_level_reqs(
                         expression = get_expression(envDef.envValue, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(id=None, type_="string")
+                            target = cwl.InputParameter(id=None, type_="string")
                             etool_id = "_expression_{}_EnvVarRequirement_{}".format(
                                 step_name, env_index
                             )
@@ -1026,7 +1032,7 @@ def process_level_reqs(
                     expression = get_expression(this_attr, inputs, None)
                     if expression:
                         modified = True
-                        target = cwl.WorkflowInputParameter(id=None, type_="long")
+                        target = cwl.InputParameter(id=None, type_="long")
                         etool_id = "_expression_{}_ResourceRequirement_{}".format(
                             step_name, attr
                         )
@@ -1053,7 +1059,7 @@ def process_level_reqs(
                         target_type = cwl.InputArraySchema(
                             ["File", "Directory"], "array", None, None
                         )
-                        target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                        target = cwl.InputParameter(id=None, type_=target_type)
                         etool_id = "_expression_{}_InitialWorkDirRequirement".format(
                             step_name
                         )
@@ -1089,7 +1095,7 @@ def process_level_reqs(
                             target_type = cwl.InputArraySchema(
                                 ["File", "Directory"], "array", None, None
                             )
-                            target = cwl.WorkflowInputParameter(
+                            target = cwl.InputParameter(
                                 id=None,
                                 type_=target_type,
                             )
@@ -1146,7 +1152,7 @@ return result; }"""
                                     else:
                                         new_expression = expression
                                     d_target_type = ["File", "Directory"]
-                                    target = cwl.WorkflowInputParameter(
+                                    target = cwl.InputParameter(
                                         id=None,
                                         type_=d_target_type,
                                     )
@@ -1176,7 +1182,7 @@ return result; }"""
                                 )
                                 if expression:
                                     modified = True
-                                    target = cwl.WorkflowInputParameter(
+                                    target = cwl.InputParameter(
                                         id=None,
                                         type_="string",
                                     )
@@ -1254,7 +1260,7 @@ def traverse_CommandLineTool(
                     inp_id = f"_arguments_{index}"
                     etool_id = f"_expression_{step_id}{inp_id}"
                     target_type = "Any"
-                    target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                    target = cwl.InputParameter(id=None, type_=target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1280,7 +1286,7 @@ def traverse_CommandLineTool(
                     inp_id = f"_arguments_{index}"
                     etool_id = f"_expression_{step_id}{inp_id}"
                     target_type = "Any"
-                    target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                    target = cwl.InputParameter(id=None, type_=target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1306,7 +1312,7 @@ def traverse_CommandLineTool(
                 inp_id = f"_{streamtype}"
                 etool_id = f"_expression_{step_id}{inp_id}"
                 target_type = "string"
-                target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                target = cwl.InputParameter(id=None, type_=target_type)
                 replace_step_clt_expr_with_etool(
                     expression, etool_id, parent, target, step, replace_etool
                 )
@@ -1346,7 +1352,7 @@ def traverse_CommandLineTool(
                     inp_id = "_{}_glob".format(outp.id.split("#")[-1])
                     etool_id = f"_expression_{step_id}{inp_id}"
                     glob_target_type = ["string", cwl.ArraySchema("string", "array")]
-                    target = cwl.WorkflowInputParameter(id=None, type_=glob_target_type)
+                    target = cwl.InputParameter(id=None, type_=glob_target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1382,7 +1388,7 @@ def traverse_CommandLineTool(
                     sub_wf_outputs = cltool_step_outputs_to_workflow_outputs(
                         step, etool_id, outp_id
                     )
-                    self_type = cwl.WorkflowInputParameter(
+                    self_type = cwl.InputParameter(
                         id=None,
                         type_=cwl.InputArraySchema("File", "array", None, None),
                     )
@@ -1413,9 +1419,9 @@ def traverse_CommandLineTool(
                         inp.linkMerge = None
                     if replace_etool:
                         processes = [parent]
-                        final_etool: Union[
-                            cwl.CommandLineTool, cwl.ExpressionTool
-                        ] = etool_to_cltool(etool, find_expressionLib(processes))
+                        final_etool: Union[cwl.CommandLineTool, cwl.ExpressionTool] = (
+                            etool_to_cltool(etool, find_expressionLib(processes))
+                        )
                     else:
                         final_etool = etool
                     etool_step = cwl.WorkflowStep(
@@ -1559,7 +1565,7 @@ def replace_step_clt_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: cwl.WorkflowInputParameter,
+    target: cwl.InputParameter,
     step: cwl.WorkflowStep,
     replace_etool: bool,
     self_name: Optional[str] = None,
@@ -1594,7 +1600,7 @@ def replace_clt_hintreq_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: cwl.WorkflowInputParameter,
+    target: cwl.InputParameter,
     step: cwl.WorkflowStep,
     replace_etool: bool,
     self_name: Optional[str] = None,
@@ -1629,7 +1635,7 @@ def replace_clt_hintreq_expr_with_etool(
 
 def cltool_inputs_to_etool_inputs(
     tool: cwl.CommandLineTool,
-) -> List[cwl.WorkflowInputParameter]:
+) -> List[cwl.InputParameter]:
     """Copy CommandLineTool input objects into the equivalent ExpressionTool input objects."""
     inputs = yaml.comments.CommentedSeq()
     if tool.inputs:
@@ -1637,7 +1643,7 @@ def cltool_inputs_to_etool_inputs(
             clt_inp_id = clt_inp.id.split("#")[-1].split("/")[-1]
             if not clt_inp_id.startswith("_"):
                 inputs.append(
-                    cwl.WorkflowInputParameter(
+                    cwl.InputParameter(
                         id=clt_inp_id,
                         label=clt_inp.label,
                         secondaryFiles=clt_inp.secondaryFiles,
@@ -1693,8 +1699,8 @@ def cltool_step_outputs_to_workflow_outputs(
 
 def generate_etool_from_expr2(
     expr: str,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
-    inputs: Sequence[Union[cwl.WorkflowInputParameter, cwl.CommandInputParameter]],
+    target: cwl.InputParameter,
+    inputs: Sequence[Union[cwl.InputParameter, cwl.CommandInputParameter]],
     self_name: Optional[str] = None,
     process: Optional[Union[cwl.CommandLineTool, cwl.ExpressionTool]] = None,
     extra_processes: Optional[
@@ -1814,12 +1820,12 @@ def traverse_step(
                     raise WorkflowException("target not found")
                 input_source_id = None
                 source_type: Optional[
-                    Union[List[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]
+                    Union[List[cwl.InputParameter], cwl.InputParameter]
                 ] = None
                 if inp.source:
                     if isinstance(inp.source, MutableSequence):
                         input_source_id = []
-                        source_types: List[cwl.WorkflowInputParameter] = []
+                        source_types: List[cwl.InputParameter] = []
                         for source in inp.source:
                             source_id = source.split("#")[-1]
                             input_source_id.append(source_id)
@@ -1833,7 +1839,7 @@ def traverse_step(
                             else:
                                 if temp_type not in source_types:
                                     source_types.append(temp_type)
-                        source_type = cwl.WorkflowInputParameter(
+                        source_type = cwl.InputParameter(
                             id=None,
                             type_=cwl.ArraySchema(source_types, "array"),
                         )
@@ -1900,10 +1906,10 @@ def traverse_step(
     return modified
 
 
-def workflow_step_to_WorkflowInputParameters(
+def workflow_step_to_InputParameters(
     step_ins: List[cwl.WorkflowStepInput], parent: cwl.Workflow, except_in_id: str
-) -> List[cwl.WorkflowInputParameter]:
-    """Create WorkflowInputParameters to match the given WorkflowStep inputs."""
+) -> List[cwl.InputParameter]:
+    """Create InputParameters to match the given WorkflowStep inputs."""
     params = []
     for inp in step_ins:
         if not inp.id:
@@ -1915,10 +1921,18 @@ def workflow_step_to_WorkflowInputParameters(
             )
             if isinstance(param, list):
                 for p in param:
+                    if not p.type_:
+                        raise WorkflowException(
+                            f"Don't know how to get type id for {p!r}."
+                        )
                     p.id = inp_id
                     p.type_ = clean_type_ids(p.type_)
                     params.append(p)
             else:
+                if not param.type_:
+                    raise WorkflowException(
+                        f"Don't know how to get type id for {param!r}."
+                    )
                 param.id = inp_id
                 param.type_ = clean_type_ids(param.type_)
                 params.append(param)
@@ -1929,26 +1943,24 @@ def replace_step_valueFrom_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     step: cwl.WorkflowStep,
     step_inp: cwl.WorkflowStepInput,
     original_process: Union[cwl.CommandLineTool, cwl.ExpressionTool],
     original_step_ins: List[cwl.WorkflowStepInput],
     source: Optional[Union[str, List[str]]],
     replace_etool: bool,
-    source_type: Optional[
-        Union[cwl.WorkflowInputParameter, List[cwl.WorkflowInputParameter]]
-    ] = None,
+    source_type: Optional[Union[cwl.InputParameter, List[cwl.InputParameter]]] = None,
 ) -> None:
     """Replace a WorkflowStep level 'valueFrom' expression with a sibling ExpressionTool step."""
     if not step_inp.id:
         raise WorkflowException(f"Missing id in {step_inp}.")
     step_inp_id = step_inp.id.split("/")[-1]
-    etool_inputs = workflow_step_to_WorkflowInputParameters(
+    etool_inputs = workflow_step_to_InputParameters(
         original_step_ins, workflow, step_inp_id
     )
     if source:
-        source_param = cwl.WorkflowInputParameter(id="self", type_="Any")
+        source_param = cwl.InputParameter(id="self", type_="Any")
         # TODO: would be nicer to derive a proper type; but in the face of linkMerge, this is easier for now
         etool_inputs.append(source_param)
     temp_etool = generate_etool_from_expr2(
@@ -1972,8 +1984,6 @@ def replace_step_valueFrom_expr_with_etool(
     if source:
         wf_step_inputs.append(cwl.WorkflowStepInput(id="self", source=step_inp.source))
     for wf_step_input in wf_step_inputs:
-        if not wf_step_input.id:
-            continue
         wf_step_input.id = wf_step_input.id.split("/")[-1]
         if wf_step_input.valueFrom:
             wf_step_input.valueFrom = None
