@@ -100,9 +100,11 @@ def run(args: argparse.Namespace) -> int:
             if not isinstance(refactored, MutableSequence):
                 result = save(
                     refactored,
-                    base_url=refactored.loadingOptions.fileuri
-                    if refactored.loadingOptions.fileuri
-                    else "",
+                    base_url=(
+                        refactored.loadingOptions.fileuri
+                        if refactored.loadingOptions.fileuri
+                        else ""
+                    ),
                 )
             #   ^^ Setting the base_url and keeping the default value
             #      for relative_uris=True means that the IDs in the generated
