@@ -579,8 +579,10 @@ def param_for_source_id(
         "param {} not found in {}\n{}.".format(
             sourcename,
             yaml.main.round_trip_dump(cwl.save(process)),
-            f" or\n {yaml.main.round_trip_dump(cwl.save(parent))}"
-            if parent is not None
-            else "",
+            (
+                f" or\n {yaml.main.round_trip_dump(cwl.save(parent))}"
+                if parent is not None
+                else ""
+            ),
         )
     )
